@@ -14,102 +14,9 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "misc.h"
-#include <gdk/gdkkeysyms.h>
-
-
-/******************************************************************************
-*                                                                             *
-* ja:メッセージボックス関数群                                                 *
-*                                                                             *
-******************************************************************************/
-/* ja:ボタンが押された */
-static void
-message_box_clicked (GtkWidget *widget,
-                     GtkWidget *dialog)
-{
-  *(gint *)g_object_get_data (G_OBJECT (dialog), "user_data")
-                    = (gint)g_object_get_data (G_OBJECT (widget), "user_data");
-  gtk_widget_destroy (dialog);
-}
-
-
-/* ja:ESCが押された */
-static gboolean
-message_box_dialog_key_press (GtkWidget   *widget,
-                              GdkEventKey *event,
-                              gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
-  return FALSE;
-}
-
-
-/*  ja:メッセージボックスを表示する
-    title,タイトル
-     text,本文
-      def,デフォルトのボタン
-      ...,ボタンのラベル
-      RET,押されたボタン(-1:キャンセル)                                     */
-gint
-misc_message_box (const gchar *title,
-                  const gchar *text,
-                  const gint def, ...)
-{
-  va_list ap;
-  gchar *name;
-  gint i = 0, result = -1;
-  GtkWidget *dialog, *button, *label, *hbox0, *hbox1, *vbox, *focus = NULL;
-
-  va_start (ap, def);
-  /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), title);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                            G_CALLBACK (message_box_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy", gtk_main_quit, NULL);
-  g_object_set_data (G_OBJECT (dialog), "user_data", &result);
-  /* ja:ラベル */
-  label = gtk_label_new(text);
-  /* ja:ボックス */
-  hbox0 = gtk_hbox_new (FALSE, SPACING);
-  /* ja:ボタン */
-  while ((name = va_arg (ap, gchar *)))
-    {
-      button = gtk_button_new_with_mnemonic (name);
-      g_signal_connect (G_OBJECT (button), "clicked",
-                                    G_CALLBACK (message_box_clicked), dialog);
-      g_object_set_data (G_OBJECT (button), "user_data", (gpointer)i);
-      GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-      if (i == def)
-        focus = button;
-      gtk_box_pack_start (GTK_BOX (hbox0), button, FALSE, FALSE, 0);
-      i++;
-    }
-  va_end (ap);
-
-  /* ja:ボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
-  gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-  hbox1 = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox1), hbox0, TRUE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (vbox), hbox1, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), vbox);
-
-  /* ja:表示 */
-  if (focus)
-    gtk_widget_grab_focus (focus);
-
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
-
-  return result;
-}
 
 
 /******************************************************************************
@@ -660,12 +567,12 @@ misc_str_to_float (gint        *value,
      flag,TRUE:符号あり,FALSE:符号なし
       RET,文字列                                                            */
 gchar *
-misc_str_from_array (gconstpointer  *array,
-                     const gsize     size,
-                     const gint      bits,
-                     const gint      radix,
-                     const gint      wide,
-                     const gboolean  flag)
+misc_str_from_array (gconstpointer  array,
+                     const gsize    size,
+                     const gint     bits,
+                     const gint     radix,
+                     const gint     wide,
+                     const gboolean flag)
 {
   gchar *p, *text = NULL;
   gint i, leng, length = 0;
@@ -775,149 +682,3 @@ misc_str_to_array (gsize          *size,
   g_free (p);
   return array;
 }
-
-
-/******************************************************************************
-*                                                                             *
-* ISO-10646                                                                   *
-*                                                                             *
-******************************************************************************/
-/*  ja:マルチバイト文字列→ワイド文字列
-       src,マルチバイト文字列
-    srclen,文字数(-1:NULL終了)
-       dst,ワイド文字列
-    dstlen,文字数
-       RET,文字数                                                           */
-gssize
-misc_multibyte_to_widechar (const gchar  *src,
-                            const gssize  srclen,
-                            guint16      *dst,
-                            const gssize  dstlen)
-{
-  gssize i, j, leng;
-
-  if (!src)
-    return 0;
-  leng = srclen < 0 ? g_strlen (src) + 1 : srclen;
-  i = j = 0;
-  if (!dst || dstlen <= 0)  /* ja:必要な文字数を数える */
-    while (i < leng)
-      {
-        if (i + 1 < leng && 0xc0 <= (guint8)src[i] && (guint8)src[i] <= 0xdf)
-          i += 2;
-        else if (i + 2 < leng && 0xe0 <= (guint8)src[i])
-          i += 3;
-        else
-          i++;
-        j++;
-      }
-  else                      /* ja:変換する */
-    while (i < leng && j < dstlen)
-      {
-        if (i + 1 < leng && 0xc0 <= (guint8)src[i] && (guint8)src[i] <= 0xdf)
-          {
-            dst[j] = (src[i] & 0x1f) << 6 | (src[i + 1] & 0x3f);
-            i += 2;
-          }
-        else if (i + 2 < leng && 0xe0 <= (guint8)src[i])
-          {
-            dst[j] = (src[i] & 0xf) << 12 | (src[i + 1] & 0x3f) << 6
-                                                        | (src[i + 2] & 0x3f);
-            i += 3;
-          }
-        else
-          {
-            dst[j] = src[i];
-            i++;
-          }
-        j++;
-      }
-  return j;
-}
-
-
-/*  ja:ワイド文字列→マルチバイト文字列
-       src,ワイド文字列
-    srclen,文字数(-1:NULL終了)
-       dst,マルチバイト文字列
-    dstlen,文字数
-       RET,文字数                                                           */
-gssize
-misc_widechar_to_multibyte (const guint16 *src,
-                            const gssize   srclen,
-                            gchar         *dst,
-                            const gssize   dstlen)
-{
-  gssize i, j, leng;
-
-  if (!src)
-    return 0;
-  if (srclen < 0)
-    {
-      for (leng = 0; src[leng] > 0; leng++);
-        leng++;
-    }
-  else
-    {
-      leng = srclen;
-    }
-  j = 0;
-  if (!dst || dstlen <= 0)  /* ja:必要な文字数を数える */
-    for (i = 0; i < leng; i++)
-      if (src[i] <= 0x007f)
-        j++;
-      else if (src[i] <= 0x07ff)
-        j += 2;
-      else
-        j += 3;
-  else                      /* ja:変換する */
-    for (i = 0; i < leng && j < dstlen; i++)
-      if (j + 1 == dstlen || src[i] <= 0x007f)
-        {
-          dst[j++] = src[i];
-        }
-      else if (j + 2 == dstlen || src[i] <= 0x07ff)
-        {
-          dst[j++] = 0xc0 | src[i] >> 6;
-          dst[j++] = 0x80 | (src[i] & 0x3f);
-        }
-      else
-        {
-          dst[j++] = 0xe0 | src[i] >> 12;
-          dst[j++] = 0x80 | (src[i] >> 6 & 0x3f);
-          dst[j++] = 0x80 | (src[i] & 0x3f);
-        }
-  return j;
-}
-
-
-/*  ja:マルチバイト文字列→ワイド文字列
-    src,マルチバイト文字列
-    RET,ワイド文字数,NULL:エラー                                            */
-guint16 *
-misc_multistring_to_widestring (const gchar *src)
-{
-  gssize leng;
-  guint16 *dst;
-
-  leng = misc_multibyte_to_widechar (src, -1, NULL, -1);
-  dst = g_malloc (leng * sizeof (guint16));
-  misc_multibyte_to_widechar (src, -1, dst, leng);
-  return dst;
-}
-
-
-/*  ja:ワイド文字列→マルチバイト文字列
-    src,ワイド文字列
-    RET,マルチバイト文字列,NULL:エラー                                      */
-gchar *
-misc_widestring_to_multistring (const guint16 *src)
-{
-  gssize leng;
-  gchar *dst;
-
-  leng = misc_widechar_to_multibyte (src, -1, NULL, -1);
-  dst = g_malloc (leng * sizeof (gchar));
-  misc_widechar_to_multibyte (src, -1, dst, leng);
-  return dst;
-}
